clear all
capture clear
capture log close
capture program drop _all
cd "O:\mentalhealth\data\"
set more off
set maxvar 12000

global results "O:\mentalhealth\tables_rep\"

log using "O:\mentalhealth\tables_rep\table9a.log", tex replace


use sl_ind, clear
keep if year >=1992 & year<= 2004
keep lopenr year pinc days_sl_ diagslP 
merge m:1 lopenr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", keepusing(foedselsaar kjoenn) 
rename _merge merge1
rename foedselsaar _yob
drop if _yob <= 1945 
fillin lopenr year  

keep if year >=1992 & year<= 2004

bys lopenr: egen yob=max(_yob)
drop _yob
*keep if yob >=1957 & yob<= 1979
ge age = year-yob
keep if age >=25 & age <= 30

drop age yob _fillin merge1
ge not_elig = pinc==0 | pinc==.
ge any_sl = days_sl_ > 0 if not_elig!=1
ge any_slp = diagslP > 0  if not_elig!=1
collapse (min) not_elig (max) any_sl any_slp pinc, by(lopenr)
duplicates drop
save sl_temp, replace


*----------------------------------------------------------------------------
*parents
*----------------------------------------------------------------------------
use "S:\Project\DemoSos2\data2020\MFR\MFR.dta", clear
rename lopenummer_barn lopenr
rename lopenummer_mor lopenr_mor
rename lopenummer_far lopenr_far
ge faar = year(fdato)
ge fmnd = month(fdato)
bys lopenr_mor fdato: ge plural = _N
destring fmnd, replace

drop if lopenr==""
drop if lopenr_mor==""

* sample restrictions
keep if faar >= 1988
count

gen age_mbirth = faar - mor_faar
gen age_fbirth = faar - far_faar

gen mor_age_1992 = 1992	- mor_faar
gen far_age_1992 = 1992	- far_faar

gen mor_age_2004 = 2004	- mor_faar
gen far_age_2004 = 2004	- far_faar

gen sample_25_30 = 1
replace sample_25_30 = 0 if (mor_age_1992>30 | mor_age_2004<25) 
replace sample_25_30 = 0 if (far_age_1992>30 | far_age_2004<25) 

gen sample_30_35 = 1
replace sample_30_35 = 0 if (mor_age_1992>35 | mor_age_2004<30) 
replace sample_30_35 = 0 if (far_age_1992>35 | far_age_2004<30) 
keep if sample_25_30 == 1 | sample_30_35 == 1

keep lopenr_far lopenr_mor
duplicates drop
save indiv, replace

keep lopenr_mor 
rename lopenr_mor lopenr
duplicates drop
save parents, replace

use indiv, clear
keep lopenr_far 
rename lopenr_far lopenr
append using parents
drop if lopenr==""
duplicates drop
merge 1:1 lopenr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", keepusing(foedselsaar kjoenn invkat)  
count if foedselsaar  >=1957 & foedselsaar <= 1979
ge notparent = _merge == 2
drop _merge
*drop individuals that died too youyng
merge 1:m lopenr using "S:\Project\DemoSos2\data2020\DAR\DAR.dta", keepusing(dodsaar)
duplicates drop
drop if dodsaar < 1988
keep if foedselsaar  >=1957 & foedselsaar <= 1979
drop _merge
save parents, replace

erase indiv.dta



use parents, clear
rename kjoenn male 
destring male, replace
recode male (2=0) 
gen  foreign = invkat!="A" if invkat!=""

merge 1:1 lopenr using edu_max, keep(3) nogen
tostring temp, replace
ge bu_1 = substr(temp,1,1)
destring bu_1, replace
ge college = inlist(bu_1, 6, 7, 8) 
merge 1:1 lopenr using sl_temp, keep(3)
drop _m



foreach var in male foedselsaar any_slp any_sl pinc not_elig foreign college  {
	eststo c`var': reg `var' notparent  , robust
	su `var' if e(sample), d
	estadd r(mean): c`var'
	est store c`var'
	
}

su notparent
esttab cmale cfoedselsaar cany_slp cany_sl cpinc cnot_elig cforeign ccollege using "$results/table9a.tex", replace booktabs fragment nolines noconstant b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) stats(mean N, fmt(%9.3g))  label

log close