clear all
capture clear
capture log close
capture program drop _all
set maxvar 100000
set max_memory 120g
cd "O:\mentalhealth\data\"
set more off


*----------------------------------------------------------------------------
*birth registry
*----------------------------------------------------------------------------
use "S:\Project\DemoSos2\data2020\MFR\MFR.dta", clear
rename lopenummer_barn lopenr
rename lopenummer_mor lopenr_mor
rename lopenummer_far lopenr_far
ge faar = year(fdato)
ge fmnd = month(fdato)
bys lopenr_mor fdato: ge plural = _N
destring fmnd, replace

drop if lopenr==""
drop if lopenr_mor==""
sort lopenr_mor lopenr

ge married=0
replace married=1 if sivst==1
ge notsingle=married
replace notsingle=1 if sivst==2

ge smoking_end=0 if royk_avsl==1
replace smoking_end=1 if royk_avsl==2 | royk_avsl==3
replace smoking_end=1 if royk_motsetter_seg==1
ge smoking_start=0 if royk_beg==1
replace smoking_start=1 if royk_beg==2 | royk_beg==3
replace smoking_start=1 if royk_motsetter_seg==1
replace ksnitt=0 if ksnitt==.
replace ksnitt=1 if ksnitt==1 | ksnitt==2 | ksnitt==3

generate str first = substr(mors_helse_foer, 1,1)
replace first="1" if first=="F"
replace first="1" if first=="B"
destring first, replace
g health_start=0 if first==.
replace health_start=1 if first==1

ge IVF=0
replace IVF=1 if art>=1 & art<=9


* sample restrictions
keep if faar >= 1985 &  faar <= 2010
count

gen age_mbirth = faar - mor_faar
gen age_fbirth = faar - far_faar

gen mor_age_1992 = 1992	- mor_faar
gen far_age_1992 = 1992	- far_faar

gen mor_age_2004 = 2004	- mor_faar
gen far_age_2004 = 2004	- far_faar

gen sample_25_30 = 1
replace sample_25_30 = 0 if (mor_age_1992>30 | mor_age_2004<25) 
replace sample_25_30 = 0 if (far_age_1992>30 | far_age_2004<25) 

gen sample_30_35 = 1
replace sample_30_35 = 0 if (mor_age_1992>35 | mor_age_2004<30) 
replace sample_30_35 = 0 if (far_age_1992>35 | far_age_2004<30) 

keep if sample_25_30 == 1 | sample_30_35 == 1
count
keep married notsingle smoking_start smoking_end IVF vekt apgar1 apgar5 ksnitt svlen age_mbirth age_fbirth mor_faar mfmnd far_faar ffmnd kjonn spabort_12 faar fmnd paritet fdato sample_25_30 sample_30_35 lopenr lopenr_mor lopenr_far
save sample_children, replace

*----------------------------------------------------------------------------
* background
*----------------------------------------------------------------------------
use  "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", clear
duplicates drop
gen  foreign = invkat!="A" if invkat!=""
rename (mor_lnr far_lnr kjoenn foedselsaar) (lopenr_mor lopenr_far sex yob) 
keep sex yob lopenr_far lopenr_mor foreign lopenr
save background, replace


**------------------------------------------------------------------------------*
*Municpality 
**------------------------------------------------------------------------------*
use "S:\Project\DemoSos2\data2020\Befolkn\Demogr\tidspunktbestemte_var.dta", clear
rename  bostedskommune bokomm
drop bydel
ge yob = aar
rename lopenr lopenr_mor 
merge 1:m lopenr_mor yob using background, keep(2 3) nogen
save background_wmun, replace


*----------------------------------------------------------------------------
** information on medical leave
*----------------------------------------------------------------------------
use "S:\Project\DemoSos2\data2020\NAV\sykep_1989_2019.dta" , clear
ge days =  SPTOM-ARBUF
ge year_start = year(ARBUF)
ge diag_sl = substr(DIAGNOSE,1,1) 
replace diag_sl="L" if diag_sl=="l" 

keep lopenr days year_start diag_sl 

collapse (sum) day, by(lopenr year_start diag_sl)
foreach k in 0 A B D E F G H I J K L N O P Q R S T U V X Y Z {
	ge aux = days if diag_sl=="`k'"
	bys lopenr year_start: egen diagsl`k' = sum(aux)
	drop aux
}  
bys lopenr year_start: egen total_days_sl = sum(days)
drop diag_sl days
duplicates drop
keep if year_start >= 1992
rename year_start year
save sick_leave, replace


*specific conditions
use "S:\Project\DemoSos2\data2020\NAV\sykep_1989_2019.dta" , clear
ge days =  SPTOM-ARBUF
ge year_start = year(ARBUF)
rename DIAGNOSE diagnose

ge mus = regexm(diagnose, "L01") |	regexm(diagnose, "L02") | regexm(diagnose, "L03") |	regexm(diagnose, "L04") | regexm(diagnose, "L05") |	regexm(diagnose, "L07") | ///
			regexm(diagnose, "L08") |	regexm(diagnose, "L09") | regexm(diagnose, "L10") |	regexm(diagnose, "L11") | regexm(diagnose, "L12") |	regexm(diagnose, "L13") | ///
			regexm(diagnose, "L14") |	regexm(diagnose, "L15") | regexm(diagnose, "L16") |	regexm(diagnose, "L17") | regexm(diagnose, "L18") |	regexm(diagnose, "L19") | ///	
			regexm(diagnose, "L20") |	regexm(diagnose, "L26") | regexm(diagnose, "L27") |	regexm(diagnose, "L28") | regexm(diagnose, "L29")
ge muf = regexm(diagnose, "L72") | regexm(diagnose, "L73") | regexm(diagnose, "L74") | regexm(diagnose, "L75") | regexm(diagnose, "L76") | regexm(diagnose, "L77") | regexm(diagnose, "L78") |regexm(diagnose, "L79") |regexm(diagnose, "L80") |regexm(diagnose, "L81") 
ge muo =  regexm(diagnose, "L70") | regexm(diagnose, "L71") | regexm(diagnose, "L82") | regexm(diagnose, "L83") | regexm(diagnose, "L84") | regexm(diagnose, "L85") | regexm(diagnose, "L86") |regexm(diagnose, "L87") |regexm(diagnose, "L88") |regexm(diagnose, "L89") | regexm(diagnose, "L90") | regexm(diagnose, "L91") | regexm(diagnose, "L92") | regexm(diagnose, "L93") | regexm(diagnose, "L94") | regexm(diagnose, "L95") | regexm(diagnose, "L96") | regexm(diagnose, "L97") | regexm(diagnose, "L98") | regexm(diagnose, "L99") 

ge can = regexm(diagnose, "A79") | ///
			regexm(diagnose, "B72") |regexm(diagnose, "B73") | regexm(diagnose, "B74") |regexm(diagnose, "B75") | ///	
			regexm(diagnose, "D74") |regexm(diagnose, "D75") | regexm(diagnose, "D76") | regexm(diagnose, "D77") | regexm(diagnose, "D78") | /// 
			regexm(diagnose, "F74") | /// 
			regexm(diagnose, "H75") | ///
			regexm(diagnose, "K72") | ///
			regexm(diagnose, "L71") | regexm(diagnose, "L97") | ///
			regexm(diagnose, "N74") |regexm(diagnose, "N75") | regexm(diagnose, "N76") | ///
			regexm(diagnose, "R84") |regexm(diagnose, "R85") | regexm(diagnose, "R86") | ///
			regexm(diagnose, "S77") |regexm(diagnose, "S78") | regexm(diagnose, "S79") | regexm(diagnose, "S80") | ///
			regexm(diagnose, "T71") |regexm(diagnose, "T72") | regexm(diagnose, "T73") | ///
			regexm(diagnose, "S77") |regexm(diagnose, "S78") | regexm(diagnose, "S79") | regexm(diagnose, "S80") | ///
			regexm(diagnose, "U75") |regexm(diagnose, "U76") | regexm(diagnose, "U77") | regexm(diagnose, "U78") | regexm(diagnose, "U79") | ///
			regexm(diagnose, "W72") |regexm(diagnose, "W73") | ///
			regexm(diagnose, "X75") |regexm(diagnose, "X76") | regexm(diagnose, "X77") | regexm(diagnose, "X78") | regexm(diagnose, "X79") |  regexm(diagnose, "X80") |  regexm(diagnose, "X81") | ///
			regexm(diagnose, "Y77") |regexm(diagnose, "Y78") | regexm(diagnose, "Y79") 
	
ge dig_chronic = regexm(diagnose, "D94") | regexm(diagnose, "D98") 

ge heart_chronic = regexm(diagnose, "K74") | regexm(diagnose, "K75") | regexm(diagnose, "K76") | regexm(diagnose, "K77") | ///
			regexm(diagnose, "K78") | regexm(diagnose, "K79") |  regexm(diagnose, "K80") |  regexm(diagnose, "K81") | ///
			regexm(diagnose, "K82") | regexm(diagnose, "K83") |  regexm(diagnose, "K84") |  regexm(diagnose, "K85") | ///
			regexm(diagnose, "K86") | regexm(diagnose, "K87") |  regexm(diagnose, "K88") |  regexm(diagnose, "K89") | ///
			regexm(diagnose, "K90") | regexm(diagnose, "K91") |  regexm(diagnose, "K92") |  regexm(diagnose, "K93") | ///
			regexm(diagnose, "K94") | regexm(diagnose, "K95") |  regexm(diagnose, "K96") |  regexm(diagnose, "K99") 
			
ge endoc_chronic = regexm(diagnose, "T81") |regexm(diagnose, "T82") | regexm(diagnose, "T83") | regexm(diagnose, "T84") | regexm(diagnose, "T85") | ///
			regexm(diagnose, "T86") |regexm(diagnose, "T87") | regexm(diagnose, "T88") | regexm(diagnose, "T89") | regexm(diagnose, "T90") | ///
			regexm(diagnose, "T91") |regexm(diagnose, "T92") | regexm(diagnose, "T93") | regexm(diagnose, "T99") 
	
ge car = regexm(diagnose, "K")


ge dep =  (regexm(diagnose , "P03")|regexm(diagnose , "P76")|regexm(diagnose , "P77")) 
ge anx =  (regexm(diagnose , "P01")|regexm(diagnose , "P02")|regexm(diagnose , "P06")|regexm(diagnose , "P74")) 
ge sub = (regexm(diagnose , "P15")|regexm(diagnose , "P16")|regexm(diagnose , "P17")|regexm(diagnose , "P18")|regexm(diagnose , "P19")) 
ge adh  = regexm(diagnose , "P81") 
ge eat = (regexm(diagnose , "P11")|regexm(diagnose , "P86"))
ge op =  regexm(diagnose, "P") & dep !=1 & anx !=1 & sub !=1 & adh !=. & eat !=.
* Psych symptoms (P00-P29)
ge ps = (regexm(diagnose , "P0")|regexm(diagnose , "P1")|regexm(diagnose , "P2"))
* Psych. diagnoses (P70-P99)
ge pd = (regexm(diagnose, "P7")|regexm(diagnose, "P8")|regexm(diagnose, "P9")) 

ge chr = dig_chronic == 1 | heart_chronic == 1 | endoc_chronic == 1

keep lopenr year_start mus muf muo can chr car dep anx sub adh eat op pd ps days

foreach var in  mus muf muo can chr car dep anx sub adh eat op pd ps days {
	ge aux = days if `var'==1
	bys lopenr year_start: egen days_`var' = sum(aux)
	drop aux
}
keep lopenr year_start days_*
duplicates drop
keep if year_start >= 1992
rename year_start year
save sick_leave_specific, replace



**------------------------------------------------------------------------------*
*education parents (max as of 2004)
**------------------------------------------------------------------------------*
use "S:\Project\DemoSos2\data2020\Utd\utdanning_70_89", clear
keep lopenr BU aar
rename BU bu
sort lopenr bu
destring bu, replace
bysort lopenr aar: egen temp=max(bu)
replace temp=. if temp==0
keep lopenr temp aar
duplicates drop
save edu_p, replace

use "S:\Project\DemoSos2\data2020\Utd\utdanning_90_19", clear
keep lopenr BU aar
keep if aar <= 2004
rename BU bu
sort lopenr bu
destring bu, replace
bysort lopenr aar: egen temp=max(bu)
replace temp=. if temp==0
keep lopenr temp aar
append using edu_p
rename aar yob
duplicates drop
save edu_p, replace

use edu_p, clear
keep lopenr temp
bysort lopenr: egen temp1=max(temp)
drop temp
rename temp1 temp
duplicates drop
save edu_max, replace



**------------------------------------------------------------------------------*
*income & sick leave for each indiv
**------------------------------------------------------------------------------*
use if aar >= 1992 using "S:\Project\DemoSos2\data2020\Inntekt\pinntekt.dta", clear
rename aar year
duplicates drop
bys lopenr year: egen pinc = max(pinnt)
drop pinnt
merge  m:1 year using cpi
keep if _m==3
drop _m
ge aux = cpi/100
replace pinc=pinc/aux
drop aux cpi
duplicates drop 
merge 1:1 lopenr year using sick_leave, keepusing(total_days_sl diagslP diagslL)
drop if year==2019
replace total_days_sl= 0 if total_days_sl==. & (pinc!=0 | pinc!=.)
for var diagslP diagslL: replace X = 0 if X == . & (pinc!=0 | pinc!=.)
replace pinc = 0 if _m==2 & total_days_sl!=.
rename total_days_sl days_sl_
drop _m
duplicates drop
merge 1:1 lopenr year using sick_leave_specific, keepusing(days_mus days_muf days_muo days_can days_chr days_car days_dep days_anx days_sub days_adh days_eat days_ps days_pd days_op)
drop if year==2019
for var days_mus days_muf days_muo days_can days_chr days_car days_dep days_anx days_sub days_adh days_ps days_pd days_eat days_op: replace X = 0 if X == . & (pinc!=0 | pinc!=.)
drop _m 
duplicates drop
merge m:1 lopenr using background
keep if _m==3
drop _m
compress
save sl_ind, replace


**------------------------------------------------------------------------------*
*parents' income when kid is 12
**------------------------------------------------------------------------------*
use "S:\Project\DemoSos2\data2020\Inntekt\pinntekt.dta", clear
rename aar year
duplicates drop
bys lopenr year: egen pinc = max(pinnt)
drop pinnt
merge  m:1 year using cpi
keep if _m==3
drop _m
ge aux = cpi/100
replace pinc=pinc/aux
drop aux cpi
duplicates drop 
rename year yob
replace yob = yob-12
save yind, replace

**------------------------------------------------------------------------------*
* sick leave by age-groups
**------------------------------------------------------------------------------*
foreach i of numlist 20 25 30 35 {
	local j = `i' + 5
	use sl_ind, clear
	keep if year <= 2004 
	ge age =year - yob
	keep if age >= `i' & age < `j'
	collapse (mean) pinc diagslP diagslL days_sl days_mus days_muf days_muo days_can days_chr days_car days_dep days_anx days_sub days_adh days_eat days_op days_ps days_pd, by(lopenr)
	foreach k in P L {
	    	rename diagsl`k' sl`k'_`i'`j'
			ge d_sl`k'_`i'`j' = sl`k'_`i'`j' > 0 if sl`k'_`i'`j'!=. 
	}
	rename days_sl days_sl_`i'`j'
	ge d_sl_`i'`j' = days_sl_`i'`j' >0 if days_sl_`i'`j'!=.
	ge o_sl_`i'`j' = days_sl_`i'`j' - slP_`i'`j'
	ge do_sl_`i'`j' = o_sl_`i'`j' > 0 if o_sl_`i'`j'!=.
	
	for var days_mus days_muf days_muo days_can days_chr days_car days_dep days_anx days_sub days_adh days_eat days_op days_ps days_pd: rename X X_`i'`j'

	rename pinc pinc_`i'`j'
	save sl`i'_`j', replace
}

**------------------------------------------------------------------------------*
* kids' middle school gpa
**------------------------------------------------------------------------------*
use lopenr stp using  "S:\Project\DemoSos2\data2020\Utd\tab_kar_grs.dta" , clear
sort lopenr stp
ge _stp = real(stp)
* attention next command
bys lopenr: egen GPAmid=mean(_stp) 
drop if lopenr==lopenr[_n-1]
keep lopenr GPAmid
save gpa, replace



**------------------------------------------------------------------------------*
* merge all
**------------------------------------------------------------------------------*
use sample_children, clear
merge 1:1 lopenr using background_wmun, keep(3) nogen
keep if foreign == 0
rename lopenr ncpid
rename lopenr_mor lopenr
merge m:1 lopenr yob using edu_p, keep(1 3) nogen
rename temp eduy_m
merge m:1 lopenr yob using yind, keep(1 3) nogen
rename pinc inc_mor
rename lopenr lopenr_mor
rename lopenr_far lopenr
merge m:1 lopenr yob using edu_p, keep(1 3) nogen
rename temp eduy_f
merge m:1 lopenr yob using yind, keep(1 3) nogen
rename pinc inc_far
rename lopenr lopenr_far
rename ncpid lopenr
merge 1:1 lopenr using gpa, keep(1 3) nogen
compress

merge 1:1 lopenr year using "kurhdoc.dta", keep(1 3) nogen

* primary care 
merge 1:m lopenr using khurh_annual_kids, keep(1 3) nogen
keep if year>=2006 & year <= 2020
foreach var in total gp er simple_contact consult blood_test labtest depression anxiety substance adhd eating other_psy diag_P non_psy ///
	diag_A diag_B diag_D diag_E diag_F diag_H diag_K diag_L diag_N diag_R diag_S diag_T diag_U ///
	asthma_allergies fractures dep_anx {
	replace `var' =0 if `var'==.
	ge d`var' = `var'>0
}


* get the hospital data
merge 1:m lopenr year using npr_sample, keep(1 3) nogen
drop npr_otherexternal
foreach var in npr_days npr npr_in npr_out npr_er npr_inf npr_cancer npr_endocr npr_mental npr_nervous npr_ear_eye npr_heart npr_resp ///
	npr_disgest npr_skin npr_muscle npr_gen npr_cong npr_other npr_injuries npr_accident npr_other_ext ///
	npr_intestinal npr_upperrespiratory npr_pneuflu npr_external npr_injury npr_poisoning  ///
	npr_maltreatment npr_fracture npr_headinj npr_mhealthkid npr_internalising npr_externalising npr_badmood npr_anxiety npr_conduct npr_eatingdis npr_accidents {
		replace `var' =0 if `var'==. & year >= 2008 & year <= 2020
}

* get psyk treat
merge 1:1 lopenr year using psyk.dta, keep(1 3) nogen
foreach var in asp_mental asp_psyk {
		replace `var' =0 if `var'==. & year >= 2008 & year <= 2020
}
  
ge age_c = year-yob
keep if age_c >= 13 & age_c <= 18
compress
save sample_new2, replace


**------------------------------------------------------------------------------*
*Modal Municpality ages 0-12
**------------------------------------------------------------------------------*
use faar lopenr using sample_new2, clear
duplicates drop
merge 1:m lopenr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\tidspunktbestemte_var.dta", keep(3) nogen keepusing(bostedskommune aar)
rename  bostedskommune bokomm
ge age = aar - faar
keep if age >= 0 & age <= 12
bys lopenr: egen mod_mun =mode(bokomm), minmode
keep lopenr mod_mun
duplicates drop
save mun0_12, replace


