clear all
capture clear
capture log close
capture program drop _all
set maxvar 100000
set max_memory 30g
cd "O:\mentalhealth\data\"
set more off


********************************************************************************
//Data with couples: foreach id and year from 2005 onward: whether individuals are in couple + ids of the members of the couple
********************************************************************************
foreach num of numlist 2005/2020 {	
	use "S:\Project\DemoSos2\data2020\Befolkn\Familie\hush_fam_`num'.dta" 
	ge year = `num'
	keep year lopenr_familie lopenr regstat_personkode parstatus
	duplicates drop
	save family_temp`num', replace
}


use family_temp2005, clear
for num 2006/2020: append using family_tempX
duplicates drop
bysort lopenr year (lopenr_familie parstatus): keep if _n == 1

destring regstat_personkode, replace
//Parents in the familie ids
gen pid = lopenr if reg != 3
bysort year lopenr_familie: egen N_pid = count(pid)
keep if inlist(N_pid, 1, 2) //Very few families with no parents/ref person or with 3
drop N_pid

for num 1 2: ge _pidX = pid if reg==X
bysort year lopenr_familie: egen pid1 = mode(_pid1), minmode
bysort year lopenr_familie: egen pid2 = mode(_pid2), minmode
replace pid2 = "" if pid1 == pid2

gen couple_status = .
replace couple_status = 1 if inlist(parstatus, "1", "2") & reg != 3 //married
replace couple_status = 2 if inlist(parstatus, "3", "5", "6", "7", "p", "u") & reg != 3 //cohabitant
replace couple_status = 3 if (inlist(parstatus, "0") & reg != 3) | reg == 3 //single (including children)

keep lopenr year couple_status pid1 pid2
compress
save couple_ids, replace

********************************************************************************
//Spouses of uncles/aunts (mothers' and fathers' siblings)
cd $pathdata_construction
use working_sample_children, clear

local nb_mor_sib = 0
ds mor_sib*_lnr
foreach var in `r(varlist)' {
	local nb_mor_sib `= `nb_mor_sib' + 1'
	}
		
//foreach moms' siblings: whether he/she is in couple + id of spouse/cohabitant. We use couple information in 2005 (or earliest available year)	
foreach i of numlist 1/`nb_mor_sib'	{
	use working_sample_children, clear
	
	keep mor_sib`i'_lnr
	keep if mor_sib`i'_lnr != ""
	duplicates drop
	
	rename mor_sib`i'_lnr lopenr
	
	merge 1:m lopenr using couple_ids, keep(1 3) nogen
	
	bysort lopenr (year): keep if _n == 1
	
	gen mor_sib`i'_lnr_status = couple_status
	
	gen mor_sib`i'_lnr_spouse = ""
	replace mor_sib`i'_lnr_spouse = pid1 if inlist(mor_sib`i'_lnr_status, 1, 2) & pid1 != lopenr & pid1!=""
	replace mor_sib`i'_lnr_spouse = pid2 if inlist(mor_sib`i'_lnr_status, 1, 2) & pid2 != lopenr & pid2!=""
	
	keep lopenr mor_sib`i'_lnr_status mor_sib`i'_lnr_spouse
	rename lopenr mor_sib`i'_lnr
	
	merge 1:m mor_sib`i'_lnr using working_sample_children, keep(2 3) nogen
	save working_sample_children, replace
}
compress
save working_sample_childrenspousesmothers, replace
********************************************************************************
use working_sample_children, clear
compress

local nb_far_sib = 0
ds far_sib*_lnr
foreach var in `r(varlist)' {
	local nb_far_sib `= `nb_far_sib' + 1'
	}
		
//foreach fathers' siblings: whether he/she is in couple + id of spouse/cohabitant. We use couple information in 2005 (or earliest available year)	
foreach i of numlist 1/`nb_far_sib'	{
	use working_sample_children, clear
	
	keep far_sib`i'_lnr
	keep if far_sib`i'_lnr != ""
	duplicates drop
	
	rename far_sib`i'_lnr lopenr
	
	merge 1:m lopenr using couple_ids, keep(1 3) nogen
	
	bysort lopenr (year): keep if _n == 1
	
	gen far_sib`i'_lnr_status = couple_status
	
	gen far_sib`i'_lnr_spouse = ""
	replace far_sib`i'_lnr_spouse = pid1 if inlist(far_sib`i'_lnr_status, 1, 2) & pid1 != lopenr & pid1!=""
	replace far_sib`i'_lnr_spouse = pid2 if inlist(far_sib`i'_lnr_status, 1, 2) & pid2 != lopenr & pid2!=""
	
	keep lopenr far_sib`i'_lnr_status far_sib`i'_lnr_spouse
	rename lopenr far_sib`i'_lnr
	
	merge 1:m far_sib`i'_lnr using working_sample_children, keep(2 3) nogen
	save working_sample_children, replace
}
compress
save working_sample_childrenspousesuncles, replace

********************************************************************************
//Spouses of parents' cousins
use working_sample_children, clear
compress

local nb_mor_cous = 0
ds mor_cous*_lnr
foreach var in `r(varlist)' {
	local nb_mor_cous `= `nb_mor_cous' + 1'
	}
		
//foreach moms' cousins: whether he/she is in couple + id of spouse/cohabitant. We use couple information in 2005 (or earliest available year)	
foreach i of numlist 1/`nb_mor_cous'	{
	use working_sample_children, clear
	
	keep mor_cous`i'_lnr
	keep if mor_cous`i'_lnr != ""
	duplicates drop
	
	rename mor_cous`i'_lnr lopenr
	
	merge 1:m lopenr using couple_ids, keep(1 3) nogen
	
	bysort lopenr (year): keep if _n == 1
	
	gen mor_cous`i'_lnr_status = couple_status
	
	gen mor_cous`i'_lnr_spouse = ""
	replace mor_cous`i'_lnr_spouse = pid1 if inlist(mor_cous`i'_lnr_status, 1, 2) & pid1 != lopenr & pid1!=""
	replace mor_cous`i'_lnr_spouse = pid2 if inlist(mor_cous`i'_lnr_status, 1, 2) & pid2 != lopenr & pid2!=""
	
	keep lopenr mor_cous`i'_lnr_status mor_cous`i'_lnr_spouse
	rename lopenr mor_cous`i'_lnr
	
	merge 1:m mor_cous`i'_lnr using working_sample_children, keep(2 3) nogen
	save working_sample_children, replace
}
compress
save working_sample_spousesunclescousins, replace


********************************************************************************
use working_sample_children, clear
compress
save working_sample_spousesunclescousins, replace

local nb_far_cous = 0
ds far_cous*_lnr
foreach var in `r(varlist)' {
	local nb_far_cous `= `nb_far_cous' + 1'
	}
		
//foreach fathers' cousins: whether he/she is in couple + id of spouse/cohabitant. We use couple information in 2005 (or earliest available year)	
foreach i of numlist 1/`nb_far_cous'	{
	use working_sample_children, clear
	
	keep far_cous`i'_lnr
	keep if far_cous`i'_lnr != ""
	duplicates drop
	
	rename far_cous`i'_lnr lopenr
	
	merge 1:m lopenr using couple_ids, keep(1 3) nogen
	
	bysort lopenr (year): keep if _n == 1
	
	gen far_cous`i'_lnr_status = couple_status
	
	gen far_cous`i'_lnr_spouse = ""
	replace far_cous`i'_lnr_spouse = pid1 if inlist(far_cous`i'_lnr_status, 1, 2) & pid1 != lopenr & pid1!=""
	replace far_cous`i'_lnr_spouse = pid2 if inlist(far_cous`i'_lnr_status, 1, 2) & pid2 != lopenr & pid2!=""
	
	keep lopenr far_cous`i'_lnr_status far_cous`i'_lnr_spouse
	rename lopenr far_cous`i'_lnr
	
	merge 1:m far_cous`i'_lnr using working_sample_children, keep(2 3) nogen
	qui compress
	save working_sample_children, replace
}

compress
save working_sample_children, replace
