clear all
capture clear
capture log close
capture program drop _all
set maxvar 100000
set max_memory 120g
cd "O:\mentalhealth\data\"
set more off


********************************************************************************
//Siblings of the spouses of parents' siblings
//1) Parents of the spouses of parents' siblings
use working_sample_children, clear

local nb_mor_sib = 0
ds mor_sib*_lnr_spouse
foreach var in `r(varlist)' {
	local nb_mor_sib `= `nb_mor_sib' + 1'
	}

foreach i of numlist 1/`nb_mor_sib'	{
	use working_sample_children, clear
	
	keep mor_sib`i'_lnr_spouse
	keep if mor_sib`i'_lnr_spouse != ""
	duplicates drop
	
	rename mor_sib`i'_lnr_spouse lopenr
	
	merge 1:m lopenr using data_dynastic_id.dta, keep(1 3) nogen keepusing(mor_lnr far_lnr)
	
	rename mor_lnr mor_sib`i'_lnr_mspouse 
	rename far_lnr mor_sib`i'_lnr_fspouse 
	
	rename lopenr mor_sib`i'_lnr_spouse
	
	keep mor_sib`i'_lnr_spouse mor_sib`i'_lnr_mspouse mor_sib`i'_lnr_fspouse
	merge 1:m mor_sib`i'_lnr_spouse using working_sample_children.dta, keep(2 3) nogen
	save working_sample_children, replace
}
**

use working_sample_children, clear
compress

local nb_far_sib = 0
ds far_sib*_lnr_spouse
foreach var in `r(varlist)' {
	local nb_far_sib `= `nb_far_sib' + 1'
	}
		
foreach i of numlist 1/`nb_far_sib'	{
	use working_sample_children, clear
	
	keep far_sib`i'_lnr_spouse
	keep if far_sib`i'_lnr_spouse != ""
	duplicates drop
	
	rename far_sib`i'_lnr_spouse lopenr
	
	merge 1:m lopenr using data_dynastic_id.dta, keep(1 3) nogen keepusing(mor_lnr far_lnr)
	
	rename mor_lnr far_sib`i'_lnr_mspouse 
	rename far_lnr far_sib`i'_lnr_fspouse 
	
	rename lopenr far_sib`i'_lnr_spouse
	
	keep far_sib`i'_lnr_spouse far_sib`i'_lnr_mspouse far_sib`i'_lnr_fspouse
	merge 1:m far_sib`i'_lnr_spouse using working_sample_children.dta, keep(2 3) nogen
	compress
	save working_sample_children, replace
}

save working_sample_children_p1, replace



//2) children of these parents
*a) mothers
foreach p in mor far {
	use working_sample_children, clear
	compress
	
	local nb_`p'_sib = 0
	ds `p'_sib*_lnr_mspouse
	foreach var in `r(varlist)' {
		local nb_`p'_sib `= `nb_`p'_sib' + 1'
		}
	
	foreach i of numlist 1/`nb_`p'_sib'	{
		use working_sample_children, clear
		
		keep `p'_sib`i'_lnr_mspouse // mothers of the spouse + her children
		drop if missing(`p'_sib`i'_lnr_mspouse) 
		rename `p'_sib`i'_lnr_mspouse mor_lnr
		
		duplicates drop
		
		merge 1:m mor_lnr using data_dynastic_id.dta, keep(1 3) nogen keepusing(lopenr) 
		
		rename lopenr `p'sib
		bysort mor_lnr (`p'sib): gen j = _n
		
		sum j
		local max_j `r(max)'
		
		reshape wide `p'sib, i(mor_lnr) j(j)
		
		gen `p'mspouse_sib`i'_children = ""
		format `p'mspouse_sib`i'_children  %14s
		replace `p'mspouse_sib`i'_children = "," + `p'sib1 if `p'sib1!=""
		
		foreach j of numlist 2/`max_j' {
			replace `p'mspouse_sib`i'_children = `p'mspouse_sib`i'_children + "," + `p'sib`j' if `p'sib`j'!=""
		}
		
		rename mor_lnr `p'_sib`i'_lnr_mspouse
		keep `p'_sib`i'_lnr_mspouse `p'mspouse_sib`i'_children
		
		merge 1:m `p'_sib`i'_lnr_mspouse using working_sample_children, keep(2 3) nogen
		compress
		save working_sample_children, replace
	}

}

save working_sample_children_p2, replace

*b) fathers
foreach p in mor far {
	use working_sample_children, clear
	
	local nb_`p'_sib = 0
	ds `p'_sib*_lnr_fspouse
	foreach var in `r(varlist)' {
		local nb_`p'_sib `= `nb_`p'_sib' + 1'
		}
	
	foreach i of numlist 1/`nb_`p'_sib'	{
		use working_sample_children, clear
		
		keep `p'_sib`i'_lnr_fspouse // mothers of the spouse + her children
		drop if missing(`p'_sib`i'_lnr_fspouse) 
		rename `p'_sib`i'_lnr_fspouse far_lnr
		
		duplicates drop
		
		merge 1:m far_lnr using data_dynastic_id.dta, keep(1 3) nogen keepusing(lopenr) 
		
		rename lopenr `p'sib
		bysort far_lnr (`p'sib): gen j = _n
		
		sum j
		local max_j `r(max)'
		
		reshape wide `p'sib, i(far_lnr) j(j)
		
		gen `p'fspouse_sib`i'_children = ""
		format `p'fspouse_sib`i'_children  %14s
		replace `p'fspouse_sib`i'_children = "," + `p'sib1 if `p'sib1!=""
		
		foreach j of numlist 2/`max_j' {
			replace `p'fspouse_sib`i'_children = `p'fspouse_sib`i'_children + "," + `p'sib`j' if `p'sib`j'!=""
		}
		
		rename far_lnr `p'_sib`i'_lnr_fspouse
		keep `p'_sib`i'_lnr_fspouse `p'fspouse_sib`i'_children
		
		merge 1:m `p'_sib`i'_lnr_fspouse using working_sample_children, keep(2 3) nogen
		save working_sample_children, replace
	}

}

save working_sample_children_p3, replace


foreach p in mor far {
	use working_sample_children, clear
		
	local nb_`p'_sib = 0
	ds `p'mspouse_sib*_children
	foreach var in `r(varlist)' {
		local nb_`p'_sib `= `nb_`p'_sib' + 1'
		}
		
	foreach i of numlist 1/`nb_`p'_sib'	{
		use working_sample_children, clear
		
		gen spouse_id = ""
		replace spouse_id = "," + `p'_sib`i'_lnr_spouse if !missing(`p'_sib`i'_lnr_spouse)
		
		replace `p'mspouse_sib`i'_children = subinstr(`p'mspouse_sib`i'_children, spouse_id, "", .)
		replace `p'mspouse_sib`i'_children = substr(`p'mspouse_sib`i'_children, 2, .)
		
		replace `p'fspouse_sib`i'_children = subinstr(`p'fspouse_sib`i'_children, spouse_id, "", .)
		replace `p'fspouse_sib`i'_children = substr(`p'fspouse_sib`i'_children, 2, .)
		
		gen `p'_sib`i'_sp_sib = ""
		replace `p'_sib`i'_sp_sib = `p'mspouse_sib`i'_children + "," + `p'fspouse_sib`i'_children if !missing(`p'mspouse_sib`i'_children) & !missing(`p'fspouse_sib`i'_children)
		replace `p'_sib`i'_sp_sib = `p'mspouse_sib`i'_children if !missing(`p'mspouse_sib`i'_children) & missing(`p'fspouse_sib`i'_children)
		replace `p'_sib`i'_sp_sib = `p'fspouse_sib`i'_children if missing(`p'mspouse_sib`i'_children) & !missing(`p'fspouse_sib`i'_children)
		
		drop spouse_id `p'mspouse_sib`i'_children `p'_sib`i'_lnr_mspouse `p'fspouse_sib`i'_children `p'_sib`i'_lnr_fspouse spouse_id
		
		save working_sample_children, replace
		
		keep `p'_sib`i'_lnr_spouse `p'_sib`i'_sp_sib
		split `p'_sib`i'_sp_sib, p(,)
		drop `p'_sib`i'_sp_sib
		duplicates drop
		reshape long `p'_sib`i'_sp_sib, i(`p'_sib`i'_lnr_spouse)
		drop _j
		duplicates drop
		drop if missing(`p'_sib`i'_sp_sib)
		count
		bysort `p'_sib`i'_lnr_spouse (`p'_sib`i'_sp_sib): gen j = _n
		sum j
		local j `r(max)'
		replace `p'_sib`i'_sp_sib = "," + `p'_sib`i'_sp_sib if j != 1
		reshape wide `p'_sib`i'_sp_sib, i(`p'_sib`i'_lnr_spouse) j(j)
		gen `p'_sib`i'_sp_sib = `p'_sib`i'_sp_sib1
		drop `p'_sib`i'_sp_sib1
		if `j' > 1 {
			foreach k of numlist 2/`j' {
				replace `p'_sib`i'_sp_sib = `p'_sib`i'_sp_sib + `p'_sib`i'_sp_sib`k' if !missing(`p'_sib`i'_sp_sib`k')
				drop `p'_sib`i'_sp_sib`k'
			}
		}
		
		rename `p'_sib`i'_sp_sib `p'_sib`i'_sp_sib_clean
		merge 1:m `p'_sib`i'_lnr_spouse using working_sample_children, keep(2 3) nogen
		drop `p'_sib`i'_sp_sib 
		rename `p'_sib`i'_sp_sib_clean `p'_sib`i'_sp_sib
		save working_sample_children, replace
	}
}

save working_sample_children_p4, replace

	
foreach p in mor far {
	use working_sample_children, clear
		
	local nb_`p'_sib = 0
	ds `p'_sib*_sp_sib
	foreach var in `r(varlist)' {
		local nb_`p'_sib `= `nb_`p'_sib' + 1'
		}
		
	foreach i of numlist 1/`nb_`p'_sib'	{
		use working_sample_children, clear
		split `p'_sib`i'_sp_sib, p(,)
		save working_sample_children, replace
	}
}


/*children's relatives:
1) parents : mor_lnr far_lnr
2) parents' siblings :  mor_sib*_lnr far_sib*_lnr	
3) spouses of parents' siblings : mor_sib*_lnr_spouse far_sib*_lnr_spouse
4) siblings of the spouses of parents' siblings : mor_sib*_sp_sib* far_sib*_sp_sib*	
5) cousins of the parents : mor_cous*_lnr far_cous*_lnr
6) spouses of the cousins of the parents : mor_cous*_lnr_spouse far_cous*_lnr_spouse
*/

use working_sample_children, clear

order mor_sib*_lnr far_sib*_lnr, sequential
order mor_sib*_lnr_spouse far_sib*_lnr_spouse, sequential
order mor_sib*_sp_sib* far_sib*_sp_sib*, sequential
order mor_cous*_lnr far_cous*_lnr, sequential
order mor_cous*_lnr_spouse far_cous*_lnr_spouse, sequential
order *status*, sequential
order mor_sib*_sp_sib far_sib*_sp_sib *status*, last
		
order lopenr mor_lnr far_lnr mor_sib*_lnr far_sib*_lnr mor_sib*_lnr_spouse far_sib*_lnr_spouse mor_sib*_sp_sib* far_sib*_sp_sib* mor_cous*_lnr far_cous*_lnr mor_cous*_lnr_spouse far_cous*_lnr_spouse mormor_lnr morfar_lnr mor_unclesaunts mormormor_lnr mormorfar_lnr morfarmor_lnr morfarfar_lnr farmor_lnr farfar_lnr far_unclesaunts farmormor_lnr farmorfar_lnr farfarmor_lnr farfarfar_lnr mor_siblings mor_cousins far_siblings far_cousins mor_sib*_sp_sib far_sib*_sp_sib *status*		

order mor_sib*_sp_sib far_sib*_sp_sib *status*, last

compress
save working_sample_children, replace
save working_sample_children_dupid, replace


********************************************************************************
//Duplicates Ids
********************************************************************************
use working_sample_children, clear
drop mor_sib*_sp_sib far_sib*_sp_sib
keep lopenr mor_lnr mor_sib*_lnr mor_sib*_lnr_spouse mor_sib*_sp_sib* mor_cous*lnr mor_cous*_lnr_spouse far_lnr far_sib*_lnr far_sib*_lnr_spouse far_sib*_sp_sib* far_cous*lnr far_cous*_lnr_spouse

ds mor_sib*_sp_sib*
local nwords:  word count `r(varlist)'
ds mor_sib*_sp_sib*
foreach var in `r(varlist)' {
	foreach i of numlist 1/`nwords' {
		capture rename `var' mor_sib_sp_sib`i'
	}
}

ds far_sib*_sp_sib*
local nwords:  word count `r(varlist)'
ds far_sib*_sp_sib*
foreach var in `r(varlist)' {
	foreach i of numlist 1/`nwords' {
		capture rename `var' far_sib_sp_sib`i'
	}
}

foreach p in mor far {
	foreach tie in sib cous {
		local nb_`p'_`tie' = 0
		ds `p'_`tie'*_lnr
		foreach var in `r(varlist)' {
			local nb_`p'_`tie' `= `nb_`p'_`tie'' + 1'
			}		
	}
}

foreach p in mor far {
	foreach tie in sib cous {
		local nb_`p'_`tie'_spouse = 0
		ds `p'_`tie'*_lnr_spouse
		foreach var in `r(varlist)' {
			local nb_`p'_`tie'_spouse `= `nb_`p'_`tie'_spouse' + 1'
			}		
	}
} 

foreach p in mor far {
	foreach tie in sib {
		local nb_`p'_`tie'_sib_spouse = 0
		ds `p'_`tie'_sp_sib*
		foreach var in `r(varlist)' {
			local nb_`p'_`tie'_sib_spouse `= `nb_`p'_`tie'_sib_spouse' + 1'
			}		
	}
}

gen id1 = mor_lnr
gen status1 = "mother"
drop mor_lnr
gen id2 = far_lnr
gen status2 = "father"
drop far_lnr

local i2 `=2+1'
foreach i of numlist 1/`nb_mor_sib' {
	gen id`i2' = mor_sib`i'_lnr 
	gen status`i2' = "mother_sibling"
	drop mor_sib`i'_lnr 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_mor_sib_spouse' {
	gen id`i2' = mor_sib`i'_lnr_spouse 
	gen status`i2' = "spouse_of_mother_siblings"
	drop mor_sib`i'_lnr_spouse
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_mor_sib_sib_spouse' {
	gen id`i2' = mor_sib_sp_sib`i' 
	gen status`i2' = "sibling_of_spouses_of_mother_siblings"
	drop mor_sib_sp_sib`i' 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_mor_cous' {
	gen id`i2' = mor_cous`i'_lnr 
	gen status`i2' = "mother_cousin"
	drop mor_cous`i'_lnr 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_mor_cous_spouse' {
	gen id`i2' = mor_cous`i'_lnr_spouse 
	gen status`i2' = "spouse_of_mother_cousins"
	drop mor_cous`i'_lnr_spouse 
	local i2 `=`i2'+1'
}

**
foreach i of numlist 1/`nb_far_sib' {
	gen id`i2' = far_sib`i'_lnr 
	gen status`i2' = "father_sibling"
	drop far_sib`i'_lnr 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_far_sib_spouse' {
	gen id`i2' = far_sib`i'_lnr_spouse 
	gen status`i2' = "spouse_of_father_siblings"
	drop far_sib`i'_lnr_spouse
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_far_sib_sib_spouse' {
	gen id`i2' = far_sib_sp_sib`i' 
	gen status`i2' = "sibling_of_spouses_of_father_siblings"
	drop far_sib_sp_sib`i' 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_far_cous' {
	gen id`i2' = far_cous`i'_lnr 
	gen status`i2' = "father_cousin"
	drop far_cous`i'_lnr 
	local i2 `=`i2'+1'
}
foreach i of numlist 1/`nb_far_cous_spouse' {
	gen id`i2' = far_cous`i'_lnr_spouse 
	gen status`i2' = "spouse_of_father_cousins"
	drop far_cous`i'_lnr_spouse 
	local i2 `=`i2'+1'
}

use working_sample_children_temp, clear
merge 1:1 lopenr using sample_children, keep(matched) keepusing(lopenr) nogen
reshape long id status, i(lopenr)

save working_sample_children_temp2, replace
 
drop _j
drop if missing(id)
bysort lopenr id: gen N = _N
tab N

keep if N>1 & !missing(N)
drop N

bysort lopenr id (status): gen j = _n
sum j
local j `r(max)'
replace status = "," + status if j != 1
reshape wide status, i(lopenr id) j(j)

gen status = status1
drop status1
foreach i of numlist 2/`j' {
	replace status = status + status`i' if !missing(status`i')
	drop status`i'
	}
	
rename id id_pb	
bysort lopenr (id): gen j = _n
reshape wide id status, i(lopenr) j(j)

merge 1:1 lopenr using working_sample_children, keep(2 3) nogen
gen duplicates_ids = !missing(id_pb1)
compress
save working_sample_children_FINAL, replace

//Next steps: twin moms, twin dads, merge with our sample, health info for kids, parents, their siblings, their cousins, the siblings' spouses and the cousins' spouses
